==> haskell-rere-0.2.0.2-7.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rere
version:              0.2.0.2
visibility:           public
id:                   rere-0.2.0.2-Nj2GUOntyXHphGNAQMIlw
key:                  rere-0.2.0.2-Nj2GUOntyXHphGNAQMIlw
license:              BSD-3-Clause
maintainer:           Artem Pelenitsyn <a@pelenitsyn.top>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  1d560506daff07645c8c6116d491374f
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rere-0.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rere-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rere-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.2-Nj2GUOntyXHphGNAQMIlw
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    containers-0.6.7 fin-0.3.2-4EQkHM8y0OJA8FKOcVjmmT parsec-3.1.16.1
    transformers-0.6.1.0 vec-0.5.1-2GDVeSx2Spk7ZyZ7CDNP23

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rere-0.2.0.2-8-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rere
version:              0.2.0.2
visibility:           public
id:                   rere-0.2.0.2-79pz3vNsKDbKI9zcN3M9B5
key:                  rere-0.2.0.2-79pz3vNsKDbKI9zcN3M9B5
license:              BSD-3-Clause
maintainer:           Artem Pelenitsyn <a@pelenitsyn.top>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  d9091a9ed0c3384edf8b56cc51e1654e
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rere-0.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rere-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rere-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.2-79pz3vNsKDbKI9zcN3M9B5
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    containers-0.6.7 fin-0.3.2-73Q0vOm3BeQJ5ufAfWM6vr parsec-3.1.16.1
    transformers-0.6.1.0 vec-0.5.1-9XrjmiNVbV6PcsQGev2dl

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
